==> soundtracker_0.3.8.orig.tar.gz: soundtracker-0.3.8/app/tips-dialog.c <==

/*
 * The Real SoundTracker - Tips dialog
 *
 * Copyright (C) 1997-1999 by the GIMP authors
 * Some adjustments for SoundTracker Copyright (C) 1999 by Michael Krause
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "config.h"

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>

#include <gtk/gtk.h>

#include "i18n.h"
#include "tips-dialog.h"
#include "preferences.h"

static int  tips_dialog_hide (GtkWidget *widget, gpointer data);
static int  tips_show_next (GtkWidget *widget, gpointer data);
static void tips_toggle_update (GtkWidget *widget, gpointer data);
static void read_tips_file (void);

static GtkWidget *tips_dialog = NULL;
static GtkWidget *tips_label;
static const char **tips_text = NULL;
static int        tips_count = 0;
static int        old_show_tips;

int last_tip = 0;
int show_tips = 1;

void
tips_dialog_create ()
{
  GtkWidget *vbox;
  GtkWidget *hbox1;
  GtkWidget *hbox2;
  GtkWidget *bbox;
  GtkWidget *vbox_bbox2;
  GtkWidget *bbox2;
  GtkWidget *button_close;
  GtkWidget *button_next;
  GtkWidget *button_prev;
  GtkWidget *vbox_check;
  GtkWidget *button_check;

#if 0
  GtkWidget *frame;
  GtkWidget *preview;
  guchar *   utemp;
  guchar *   src;
  guchar *   dest;
  int        x;
  int        y;
#endif

  if (tips_count == 0)
    {
      read_tips_file ();
    }

  if (last_tip >= tips_count || last_tip < 0)
    last_tip = 0;

  if (!tips_dialog)
    {
      tips_dialog = gtk_window_new (GTK_WINDOW_DIALOG);
      gtk_window_set_wmclass (GTK_WINDOW (tips_dialog), "tip_of_the_day", "SoundTracker");
      gtk_window_set_title (GTK_WINDOW (tips_dialog), (_("SoundTracker Tip of the day")));
      gtk_signal_connect (GTK_OBJECT (tips_dialog), "delete_event",
			  GTK_SIGNAL_FUNC (tips_dialog_hide), NULL);
      /* destroy the tips window if the mainlevel gtk_main() function is left */
      gtk_quit_add_destroy (1, GTK_OBJECT (tips_dialog));

      vbox = gtk_vbox_new (FALSE, 0);
      gtk_container_add (GTK_CONTAINER (tips_dialog), vbox);
      gtk_widget_show (vbox);

      hbox1 = gtk_hbox_new (FALSE, 5);
      gtk_container_set_border_width (GTK_CONTAINER (hbox1), 10);
      gtk_box_pack_start (GTK_BOX (vbox), hbox1, FALSE, TRUE, 0);
      gtk_widget_show (hbox1);

      hbox2 = gtk_hbox_new (FALSE, 5);
      gtk_container_set_border_width (GTK_CONTAINER (hbox2), 10);
      gtk_box_pack_end (GTK_BOX (vbox), hbox2, FALSE, TRUE, 0);
      gtk_widget_show (hbox2);
      
      bbox = gtk_hbutton_box_new ();
      gtk_box_pack_end (GTK_BOX (hbox2), bbox, FALSE, FALSE, 0);
      gtk_widget_show (bbox);

      vbox_bbox2 = gtk_vbox_new (FALSE, 0);
      gtk_box_pack_end (GTK_BOX (hbox2), vbox_bbox2, FALSE, FALSE, 15);
      gtk_widget_show (vbox_bbox2);

      bbox2 = gtk_hbox_new (TRUE, 5); 
      gtk_box_pack_end (GTK_BOX (vbox_bbox2), bbox2, TRUE, FALSE, 0);
      gtk_widget_show(bbox2);

#if 0
      preview = gtk_preview_new (GTK_PREVIEW_COLOR);
      gtk_preview_size (GTK_PREVIEW (preview), wilber_width, wilber_height);
      utemp = g_new (guchar, wilber_width * 3);
      src = (guchar *)wilber_data;
      for (y = 0; y < wilber_height; y++)
	{
	  dest = utemp;
	  for (x = 0; x < wilber_width; x++)
	    {
	      HEADER_PIXEL(src, dest);
	      dest += 3;
	    }
	  gtk_preview_draw_row (GTK_PREVIEW (preview), utemp,
				0, y, wilber_width); 
	}
      g_free(utemp);
      frame = gtk_frame_new (NULL);
      gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
      gtk_box_pack_end (GTK_BOX (hbox1), frame, FALSE, TRUE, 3);
      gtk_container_add (GTK_CONTAINER (frame), preview);
      gtk_widget_show (preview);
      gtk_widget_show (frame);
#endif

      tips_label = gtk_label_new (tips_text[last_tip]);
      gtk_label_set_justify (GTK_LABEL (tips_label), GTK_JUSTIFY_LEFT);
      gtk_box_pack_start (GTK_BOX (hbox1), tips_label, TRUE, TRUE, 3);
      gtk_widget_show (tips_label);

      button_prev = gtk_button_new_with_label ((_("Previous Tip")));
      GTK_WIDGET_UNSET_FLAGS (button_prev, GTK_RECEIVES_DEFAULT);
      gtk_signal_connect (GTK_OBJECT (button_prev), "clicked",
			  GTK_SIGNAL_FUNC (tips_show_next),
			  (gpointer) "prev");
      gtk_container_add (GTK_CONTAINER (bbox2), button_prev);
      gtk_widget_show (button_prev);

      button_next = gtk_button_new_with_label ((_("Next Tip")));
      GTK_WIDGET_UNSET_FLAGS (button_next, GTK_RECEIVES_DEFAULT);
      gtk_signal_connect (GTK_OBJECT (button_next), "clicked",
			  GTK_SIGNAL_FUNC (tips_show_next),
			  (gpointer) "next");
      gtk_container_add (GTK_CONTAINER (bbox2), button_next);
      gtk_widget_show (button_next);

      button_close = gtk_button_new_with_label ((_("Close")));
      GTK_WIDGET_SET_FLAGS (button_close, GTK_CAN_DEFAULT);
      gtk_window_set_default (GTK_WINDOW (tips_dialog), button_close);
      gtk_signal_connect (GTK_OBJECT (button_close), "clicked",
			  GTK_SIGNAL_FUNC (tips_dialog_hide), NULL);
      gtk_container_add (GTK_CONTAINER (bbox), button_close);
      gtk_widget_show (button_close);

      vbox_check = gtk_vbox_new (FALSE, 0); 
      gtk_box_pack_start (GTK_BOX (hbox2), vbox_check, FALSE, TRUE, 0);
      gtk_widget_show (vbox_check);

      button_check = gtk_check_button_new_with_label ((_("Show tip next time")));
      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_check),
				    show_tips);
      gtk_signal_connect (GTK_OBJECT (button_check), "toggled",
			  GTK_SIGNAL_FUNC (tips_toggle_update),
			  (gpointer) &show_tips);
      gtk_box_pack_start (GTK_BOX (vbox_check), button_check, TRUE, FALSE, 0);
      gtk_widget_show (button_check);

      old_show_tips = show_tips;
    }

  if (!GTK_WIDGET_VISIBLE (tips_dialog))
    {
      gtk_widget_show (tips_dialog);
    }
  else
    {
      gdk_window_raise (tips_dialog->window);
    }
}

static int
tips_dialog_hide (GtkWidget *widget,
		  gpointer data)
{
  gtk_widget_hide (tips_dialog);

  return TRUE;
}

static int
tips_show_next (GtkWidget *widget,
		gpointer  data)
{
  if (!strcmp ((char *)data, "prev"))
    {
      last_tip--;
      if (last_tip < 0)
	last_tip = tips_count - 1;
    }
  else
    {
      last_tip++;
      if (last_tip >= tips_count)
	last_tip = 0;
    }
  gtk_label_set (GTK_LABEL (tips_label), tips_text[last_tip]);
  return FALSE;
}

static void
tips_toggle_update (GtkWidget *widget,
		    gpointer   data)
{
  int *toggle_val;

  toggle_val = (int *) data;

  if (GTK_TOGGLE_BUTTON (widget)->active)
    *toggle_val = TRUE;
  else
    *toggle_val = FALSE;
}

static void
store_tip (const char *str)
{
  tips_count++;
  tips_text = g_realloc(tips_text, sizeof(char *) * tips_count);
  tips_text[tips_count - 1] = str;
}

static char const * const tips_array[] = {
    N_("Welcome to SoundTracker!\n"
       "\n"
       "If you are new to this type of program, you will want to get hold of\n"
       "some XM or MOD files first and play with them."),

    N_("You can make SoundTracker's edit mode more responsive to keyboard\n"
       "input by decreasing the mixing buffer size of the \"Editing\" object in\n"
       "the Audio Configuration."),

    N_("You can adjust the loop points in the sample editor by holding Shift\n"
       "and using the left and right mousebuttons.\n"),

    N_("If you want to know more about tracking, and how the various commands\n"
       "work, have a look at http://www.united-trackers.org/"),

    N_("You can assign samples of an instrument to the individual keys by\n"
       "activating its sample and then clicking on the keyboard in the\n"
       "instrument editor page.")
};

static void
read_tips_file (void)
{
    int i;

    for(i = 0; i < sizeof(tips_array) / sizeof(tips_array[0]); i++) {
	store_tip(gettext(tips_array[i]));
    }
}

void
tips_dialog_load_settings (void)
{
    char buf[256];
    FILE *f;

    sprintf(buf, "%s/tips", prefs_get_prefsdir());

    f = fopen(buf, "rb");
    if(f) {
	prefs_get_int(f, "show-tips", &show_tips);
	prefs_get_int(f, "last-tip", &last_tip);
	fclose(f);
    }

    return;

}

void
tips_dialog_save_settings (void)
{
    char buf[256];
    FILE *f;

    prefs_check_prefs_dir();
    sprintf(buf, "%s/tips", prefs_get_prefsdir());

    f = fopen(buf, "wb");
    if(!f)
	return;

    last_tip++;
    prefs_put_int(f, "show-tips", show_tips);
    prefs_put_int(f, "last-tip", last_tip);

    fclose(f);
    return;
}

==> soundtracker_0.6.4.orig.tar.gz: soundtracker-0.6.4/app/tips-dialog.c <==

/*
 * The Real SoundTracker - Tips dialog
 *
 * Copyright (C) 1997-2000 by the GIMP authors
 * Some adjustments for SoundTracker Copyright (C) 1999-2000 by Michael Krause
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "config.h"

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>

#include <gtk/gtk.h>

#include "i18n.h"
#include "tips-dialog.h"
#include "preferences.h"

static int  tips_dialog_hide (GtkWidget *widget, gpointer data);
static int  tips_show_next (GtkWidget *widget, gpointer data);
static void tips_toggle_update (GtkWidget *widget, gpointer data);
static void read_tips_file (void);

static GtkWidget *tips_dialog = NULL;
static GtkWidget *tips_label;
static const char **tips_text = NULL;
static int        tips_count = 0;
static int        old_show_tips;

int last_tip = 0;
int show_tips = 1;

void
tips_dialog_create ()
{
  GtkWidget *vbox;
  GtkWidget *hbox1;
  GtkWidget *hbox2;
  GtkWidget *bbox;
  GtkWidget *vbox_bbox2;
  GtkWidget *bbox2;
  GtkWidget *button_close;
  GtkWidget *button_next;
  GtkWidget *button_prev;
  GtkWidget *vbox_check;
  GtkWidget *button_check;

#if 0
  GtkWidget *frame;
  GtkWidget *preview;
  guchar *   utemp;
  guchar *   src;
  guchar *   dest;
  int        x;
  int        y;
#endif

  if (tips_count == 0)
    {
      read_tips_file ();
    }

  if (last_tip >= tips_count || last_tip < 0)
    last_tip = 0;

  if (!tips_dialog)
    {
      tips_dialog = gtk_window_new (GTK_WINDOW_DIALOG);
      gtk_window_set_wmclass (GTK_WINDOW (tips_dialog), "tip_of_the_day", "SoundTracker");
      gtk_window_set_title (GTK_WINDOW (tips_dialog), (_("SoundTracker Tip of the day")));
      gtk_signal_connect (GTK_OBJECT (tips_dialog), "delete_event",
			  GTK_SIGNAL_FUNC (tips_dialog_hide), NULL);
      /* destroy the tips window if the mainlevel gtk_main() function is left */
      gtk_quit_add_destroy (1, GTK_OBJECT (tips_dialog));

      vbox = gtk_vbox_new (FALSE, 0);
      gtk_container_add (GTK_CONTAINER (tips_dialog), vbox);
      gtk_widget_show (vbox);

      hbox1 = gtk_hbox_new (FALSE, 5);
      gtk_container_set_border_width (GTK_CONTAINER (hbox1), 10);
      gtk_box_pack_start (GTK_BOX (vbox), hbox1, FALSE, TRUE, 0);
      gtk_widget_show (hbox1);

      hbox2 = gtk_hbox_new (FALSE, 5);
      gtk_container_set_border_width (GTK_CONTAINER (hbox2), 10);
      gtk_box_pack_end (GTK_BOX (vbox), hbox2, FALSE, TRUE, 0);
      gtk_widget_show (hbox2);
      
      bbox = gtk_hbutton_box_new ();
      gtk_box_pack_end (GTK_BOX (hbox2), bbox, FALSE, FALSE, 0);
      gtk_widget_show (bbox);

      vbox_bbox2 = gtk_vbox_new (FALSE, 0);
      gtk_box_pack_end (GTK_BOX (hbox2), vbox_bbox2, FALSE, FALSE, 15);
      gtk_widget_show (vbox_bbox2);

      bbox2 = gtk_hbox_new (TRUE, 5); 
      gtk_box_pack_end (GTK_BOX (vbox_bbox2), bbox2, TRUE, FALSE, 0);
      gtk_widget_show(bbox2);

#if 0
      preview = gtk_preview_new (GTK_PREVIEW_COLOR);
      gtk_preview_size (GTK_PREVIEW (preview), wilber_width, wilber_height);
      utemp = g_new (guchar, wilber_width * 3);
      src = (guchar *)wilber_data;
      for (y = 0; y < wilber_height; y++)
	{
	  dest = utemp;
	  for (x = 0; x < wilber_width; x++)
	    {
	      HEADER_PIXEL(src, dest);
	      dest += 3;
	    }
	  gtk_preview_draw_row (GTK_PREVIEW (preview), utemp,
				0, y, wilber_width); 
	}
      g_free(utemp);
      frame = gtk_frame_new (NULL);
      gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
      gtk_box_pack_end (GTK_BOX (hbox1), frame, FALSE, TRUE, 3);
      gtk_container_add (GTK_CONTAINER (frame), preview);
      gtk_widget_show (preview);
      gtk_widget_show (frame);
#endif

      tips_label = gtk_label_new (tips_text[last_tip]);
      gtk_label_set_justify (GTK_LABEL (tips_label), GTK_JUSTIFY_LEFT);
      gtk_box_pack_start (GTK_BOX (hbox1), tips_label, TRUE, TRUE, 3);
      gtk_widget_show (tips_label);

      button_prev = gtk_button_new_with_label ((_("Previous Tip")));
      GTK_WIDGET_UNSET_FLAGS (button_prev, GTK_RECEIVES_DEFAULT);
      gtk_signal_connect (GTK_OBJECT (button_prev), "clicked",
			  GTK_SIGNAL_FUNC (tips_show_next),
			  (gpointer) "prev");
      gtk_container_add (GTK_CONTAINER (bbox2), button_prev);
      gtk_widget_show (button_prev);

      button_next = gtk_button_new_with_label ((_("Next Tip")));
      GTK_WIDGET_UNSET_FLAGS (button_next, GTK_RECEIVES_DEFAULT);
      gtk_signal_connect (GTK_OBJECT (button_next), "clicked",
			  GTK_SIGNAL_FUNC (tips_show_next),
			  (gpointer) "next");
      gtk_container_add (GTK_CONTAINER (bbox2), button_next);
      gtk_widget_show (button_next);

      button_close = gtk_button_new_with_label ((_("Close")));
      GTK_WIDGET_SET_FLAGS (button_close, GTK_CAN_DEFAULT);
      gtk_window_set_default (GTK_WINDOW (tips_dialog), button_close);
      gtk_signal_connect (GTK_OBJECT (button_close), "clicked",
			  GTK_SIGNAL_FUNC (tips_dialog_hide), NULL);
      gtk_container_add (GTK_CONTAINER (bbox), button_close);
      gtk_widget_show (button_close);

      vbox_check = gtk_vbox_new (FALSE, 0); 
      gtk_box_pack_start (GTK_BOX (hbox2), vbox_check, FALSE, TRUE, 0);
      gtk_widget_show (vbox_check);

      button_check = gtk_check_button_new_with_label ((_("Show tip next time")));
      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button_check),
				    show_tips);
      gtk_signal_connect (GTK_OBJECT (button_check), "toggled",
			  GTK_SIGNAL_FUNC (tips_toggle_update),
			  (gpointer) &show_tips);
      gtk_box_pack_start (GTK_BOX (vbox_check), button_check, TRUE, FALSE, 0);
      gtk_widget_show (button_check);

      old_show_tips = show_tips;
    }

  if (!GTK_WIDGET_VISIBLE (tips_dialog))
    {
      gtk_widget_show (tips_dialog);
    }
  else
    {
      gdk_window_raise (tips_dialog->window);
    }
}

static int
tips_dialog_hide (GtkWidget *widget,
		  gpointer data)
{
  gtk_widget_hide (tips_dialog);

  return TRUE;
}

static int
tips_show_next (GtkWidget *widget,
		gpointer  data)
{
  if (!strcmp ((char *)data, "prev"))
    {
      last_tip--;
      if (last_tip < 0)
	last_tip = tips_count - 1;
    }
  else
    {
      last_tip++;
      if (last_tip >= tips_count)
	last_tip = 0;
    }
  gtk_label_set (GTK_LABEL (tips_label), tips_text[last_tip]);
  return FALSE;
}

static void
tips_toggle_update (GtkWidget *widget,
		    gpointer   data)
{
  int *toggle_val;

  toggle_val = (int *) data;

  if (GTK_TOGGLE_BUTTON (widget)->active)
    *toggle_val = TRUE;
  else
    *toggle_val = FALSE;
}

static void
store_tip (const char *str)
{
  tips_count++;
  tips_text = g_realloc(tips_text, sizeof(char *) * tips_count);
  tips_text[tips_count - 1] = str;
}

static char const * const tips_array[] = {
    N_("Welcome to SoundTracker!\n"
       "\n"
       "If you are new to this type of program, you will want to get hold of\n"
       "some XM or MOD files first and play with them."),

    N_("You can make SoundTracker's edit mode more responsive to keyboard\n"
       "input by decreasing the mixing buffer size of the \"Editing\" object in\n"
       "the Audio Configuration."),

    N_("You can adjust the loop points in the sample editor by holding Shift\n"
       "and using the left and right mousebuttons.\n"),

    N_("If you want to know more about tracking, and how the various commands\n"
       "work, have a look at http://www.united-trackers.org/"),

    N_("You can assign samples of an instrument to the individual keys by\n"
       "activating its sample and then clicking on the keyboard in the\n"
       "instrument editor page."),

    N_("Is your cursor trapped in a number entry field?\n"
       "Just press Return or Tab to free yourself!")
};

static void
read_tips_file (void)
{
    int i;

    for(i = 0; i < sizeof(tips_array) / sizeof(tips_array[0]); i++) {
	store_tip(gettext(tips_array[i]));
    }
}

void
tips_dialog_load_settings (void)
{
    prefs_node *f;

    f = prefs_open_read("tips");
    if(f) {
	prefs_get_int(f, "show-tips", &show_tips);
	prefs_get_int(f, "last-tip", &last_tip);
	prefs_close(f);
    }

    return;
}

void
tips_dialog_save_settings (void)
{
    prefs_node *f;

    f = prefs_open_write("tips");
    if(!f)
	return;

    last_tip++;
    prefs_put_int(f, "show-tips", show_tips);
    prefs_put_int(f, "last-tip", last_tip);
    
    prefs_close(f);
    return;
}
